/*******************************************************************************
* File Name: Filter_FIR.h
* Version 2.20
*
* Description:
*  This header file contains definitions associated with the FILT component.
*
* Note:
* 
********************************************************************************
* Copyright 2008-2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(Filter_FIR_H) /* FILT Header File */
#define Filter_FIR_H

#include "cyfitter.h"
#include "CyLib.h"

extern uint8 Filter_FIR_initVar;


/***************************************
*   Conditional Compilation Parameters
***************************************/
#define Filter_FIR_DA_RAM_SIZE_CUR        (0x200u)
#define Filter_FIR_DB_RAM_SIZE_CUR        (0x200u)
#define Filter_FIR_CSA_RAM_SIZE_CUR       (0x100u)
#define Filter_FIR_CSB_RAM_SIZE_CUR       (0x100u)
#define Filter_FIR_CFSM_RAM_SIZE_CUR      (0x100u)
#define Filter_FIR_ACU_RAM_SIZE_CUR       (0x40u)

#define Filter_FIR_FIR_A_SIZE       (128u)
#define Filter_FIR_FIR_B_SIZE       (128u)
	
extern const uint8 CYCODE Filter_FIR_ChannelAFirCoefficients[Filter_FIR_FIR_A_SIZE];
extern const uint8 CYCODE Filter_FIR_ChannelBFirCoefficients[Filter_FIR_FIR_B_SIZE];


/***************************************
*     Data Struct Definition
***************************************/

/* Low power Mode API Support */
typedef struct 
{
    uint8 enableState;
    uint8 cr;
    uint8 sr;
    uint8 sema;
    uint8 saveAcu[Filter_FIR_ACU_RAM_SIZE_CUR];
}   Filter_FIR_backupStruct;


/***************************************
* FILT component function prototypes.
****************************************/

void   Filter_FIR_Start(void) ;
void   Filter_FIR_Stop(void) ;
uint8 Filter_FIR_Read8(uint8 channel) ;
uint16 Filter_FIR_Read16(uint8 channel) ;
uint32 Filter_FIR_Read24(uint8 channel) ;
void Filter_FIR_Write8(uint8 channel, uint8 sample) ;
void Filter_FIR_Write16(uint8 channel, uint16 sample) ;
void Filter_FIR_Write24(uint8 channel, uint32 sample) ;
void Filter_FIR_Sleep(void) ;
void Filter_FIR_Wakeup(void) ;
void Filter_FIR_SaveConfig(void) ;
void Filter_FIR_RestoreConfig(void) ;
void Filter_FIR_Init(void) ;
void Filter_FIR_Enable(void) ;
void Filter_FIR_SetCoherency(uint8 channel, uint8 byteSelect) ;


/*****************************************
* FILT component API Constants.
******************************************/

/* Channel Definitions */
#define Filter_FIR_CHANNEL_A             (0u)
#define Filter_FIR_CHANNEL_B             (1u)

#define Filter_FIR_CHANNEL_A_INTR        (0x08u)
#define Filter_FIR_CHANNEL_B_INTR        (0x10u)

#define Filter_FIR_ALL_INTR              (0xf8u)

#define Filter_FIR_SIGN_BIT              ((uint32)0x00800000u)
#define Filter_FIR_SIGN_BYTE             ((uint32)0xFF000000u)

/* Component's enable/disable state */
#define Filter_FIR_ENABLED               (0x01u)
#define Filter_FIR_DISABLED              (0x00u)

/* SetCoherency API constants */
#define Filter_FIR_KEY_LOW               (0x00u)
#define Filter_FIR_KEY_MID               (0x01u)
#define Filter_FIR_KEY_HIGH              (0x02u)


/*******************************************************************************
* FILT component macros.
*******************************************************************************/

#define Filter_FIR_ClearInterruptSource() \
   (Filter_FIR_SR_REG = Filter_FIR_ALL_INTR )

#define Filter_FIR_IsInterruptChannelA() \
    (Filter_FIR_SR_REG & Filter_FIR_CHANNEL_A_INTR)

#define Filter_FIR_IsInterruptChannelB() \
    (Filter_FIR_SR_REG & Filter_FIR_CHANNEL_B_INTR)


/*******************************************************************************
* FILT component DFB registers.
*******************************************************************************/

/* DFB Status register */
#define Filter_FIR_SR_REG             (* (reg8 *) Filter_FIR_DFB__SR)
#define Filter_FIR_SR_PTR             (  (reg8 *) Filter_FIR_DFB__SR)

/* DFB Control register */
#define Filter_FIR_CR_REG             (* (reg8 *) Filter_FIR_DFB__CR)
#define Filter_FIR_CR_PTR             (  (reg8 *) Filter_FIR_DFB__CR)


/*******************************************************************************
* DFB.COHER bit field defines.
*******************************************************************************/

/* STAGEA key coherency mask */
#define Filter_FIR_STAGEA_COHER_MASK    (0x03u)

/* HOLDA key coherency mask */
#define Filter_FIR_HOLDA_COHER_MASK     ((uint8)((uint8)0x03u << 4u))

/* STAGEB key coherency mask */
#define Filter_FIR_STAGEB_COHER_MASK    (0x0Cu)

/* HOLDB key coherency mask */
#define Filter_FIR_HOLDB_COHER_MASK     ((uint8)((uint8)0x0Cu << 4u))


#endif /* End FILT Header File */


/* [] END OF FILE */
